<?php /* !
 * WP Lead Hunter
 * http://www.pluginbeast.com
 * V1.2
 *
 * Copyright 2014, Plugin Beast, StormGate Ltd.
 *
 * Date: 04/12/2014
 */

	class WPLeadFinderSettings {
		
		
		private $settings;
		private $settingsKey = 'wpleadfindersettings';
		private $settingsVer = 'v1.0//17.11.14';
		private $settingsDefault = array( 

										
										'reg' => 					'1',
										'bingapikey' => 			'',
										'bingtwo' => 				0,
										'queries' =>				0,
										'bing_queries' =>			array(
											'total' => 0,
											'month' => 0,
											'last_up' => 0)


		);
		
		
		
		function WPLeadFinderSettings() {
			
			
			$this->loadFromDB();
			
			
			$this->validateAndUpdate();
			
			
			if (empty($this->settings)) $this->initCreate();
			
		}
		
		
		function validateAndUpdate(){
			$defaultsAdded = 0;
			foreach ($this->settingsDefault as $key => $val) 
				if (!isset($this->settings[$key])) {
					$this->settings[$key] = $val;
					$defaultsAdded++;
				}
			
			if ($defaultsAdded > 0) $this->saveToDB();
		}
		
		
		function initCreate(){
			
			global $socialBuzzPlugin_db_version, $socialBuzzPlugin_version;
			
			
			$defaultOptions = $this->settingsDefault;
			$defaultOptions['settingsID'] = $this->settingsVer; 
			$defaultOptions['db_version'] = $socialBuzzPlugin_db_version; 
			$defaultOptions['version'] = $socialBuzzPlugin_version; 
			$this->settings = $defaultOptions;
			$this->saveToDB();
			
		}

		
		function resetToDefaults(){
			
			global $socialBuzzPlugin_db_version, $socialBuzzPlugin_version;
			
			
			$this->settings = $this->settingsDefault;
			$this->saveToDB();

		}
		
		
		function getAll(){
			
			return $this->settings;
			
		}
		
		
		function get($key){
			
			if (empty($key) === true) return false;
			
			if (isset($this->settings[$key]))
				return $this->settings[$key];
			else
				return false;
			
		}
		
		
		function update($key,$val=''){
			
			if (empty($key) === true) return false;
			
						$this->settings[$key] = $val;		
			
			
			$this->saveToDB();
		}		
		
		
		function delete($key){
			
			if (empty($key) === true) return false;
			
			$newSettings = array();
			foreach($this->settings as $k => $v)
				if ($k != $key) $newSettings[$k] = $v;
				
			
			$this->settings = $newSettings;
						
		}
		
		
		function saveToDB(){
		
			return update_option($this->settingsKey, $this->settings);				
			
		}
		
		
		function loadFromDB(){
			
			$this->settings = get_option($this->settingsKey);
			return $this->settings;
			
		}		
		
		
		function uninstall(){
			
			
			$this->settings['uninstall'] = time();
			
			
			$this->createBackup('Pre-UnInstall Backup');
			
			
			$this->settings = NULL;
			
			
			return delete_option($this->settingsKey);
			
		}
		
		
		function createBackup($backupLabel=''){
			
			$existingBK = get_option($this->settingsKey.'_bk'); if (!is_array($existingBK)) $existingBK = array();
			$existingBK[time()] = $this->settings; 
			if (!empty($backupLabel)) $existingBK[time()]['backupLabel'] = sanitize_text_field($backupLabel); 
			update_option($this->settingsKey.'_bk',$existingBK);
			return $existingBK[time()];
			
		}
		
		
		function killBackups(){
		
			return delete_option($this->settingsKey.'_bk');
			
		}
		
		
		function getBKs(){
			
			$x = get_option($this->settingsKey.'_bk');
			
			if (is_array($x)) return $x; else return array();
			
		}
		
		
		function reloadFromBK($bkkey){
		
			$backups = get_option($this->settingsKey.'_bk');
			
			if (isset($backups[$bkkey])) if (is_array($backups[$bkkey])) {
				
				
				$this->settings = $backups[$bkkey];
				
				
				$this->saveToDB();
			
				return true;	
				
			} 
			
			return false;
				
			
		}
		
		
		
	}
	
?>